@@ -124,7 +124,7 @@ PinyinEngine::processAccelKeyEvent (guint keyval, guint keycode,
             if (!m_editors[MODE_INIT]->text ().empty ())
                 m_editors[MODE_INIT]->reset ();
             m_props.toggleModeChinese ();
-            return TRUE;
+            return FALSE;
         }
 
         if (m_input_mode == MODE_INIT &&
@@ -201,19 +201,31 @@ PinyinEngine::processKeyEvent (guint keyval, guint keycode, guint modifiers)
 #endif
 #ifdef IBUS_BUILD_ENGLISH_INPUT_MODE
                 case IBUS_v:
-                    // do not enable english mode when use double pinyin.
+                    // for full pinyin
                     if (PinyinConfig::instance ().doublePinyin ())
                         break;
                     m_input_mode = MODE_ENGLISH;
                     break;
+                case IBUS_V:
+                    // for double pinyin
+                    if (!PinyinConfig::instance ().doublePinyin ())
+                        break;
+                    m_input_mode = MODE_ENGLISH;
+                    break;
 #endif
 #ifdef IBUS_BUILD_STROKE_INPUT_MODE
                 case IBUS_u:
-                    // do not enable stroke mode when use double pinyin.
+                    // for full pinyin
                     if (PinyinConfig::instance ().doublePinyin ())
                         break;
                     m_input_mode = MODE_STROKE;
                     break;
+                case IBUS_U:
+                    // for double pinyin
+                    if (!PinyinConfig::instance ().doublePinyin ())
+                        break;
+                    m_input_mode = MODE_STROKE;
+                    break;
 #endif
                 }
             } else {
